--AH:ScriptId=ed0f8c77-bc57-4e09-a23a-faaa0817e4d5;2892
CREATE TABLE [ScheduledTasks]
(
	[ScheduledTask_Id] INT IDENTITY(1, 1) NOT NULL,
	[ScheduledTaskType_Code] VARCHAR(50) NOT NULL,
	[Feed_Id] INT NULL,
	[NpmConnector_Id] INT NULL,
	[MavenConnector_Id] INT NULL,
	[Frequency_Hours] INT NULL,
	[StartTimeOfDay_Minutes] INT NOT NULL,
	[EndTimeOfDay_Minutes] INT NOT NULL,
	[Active_Indicator] YNINDICATOR NOT NULL,
	[RunImmediately_User] USERNAME NULL,

	CONSTRAINT [PK__ScheduledTasks]
		PRIMARY KEY ([ScheduledTask_Id]),

	CONSTRAINT [UQ__ScheduledTasks]
		UNIQUE ([ScheduledTaskType_Code], [Feed_Id], [NpmConnector_Id], [MavenConnector_Id]),

	CONSTRAINT [FK__ScheduledTasks__Feeds]
		FOREIGN KEY ([Feed_Id])
		REFERENCES [Feeds] ([Feed_Id]),

	CONSTRAINT [FK__ScheduledTasks__NpmConnectors]
		FOREIGN KEY ([NpmConnector_Id])
		REFERENCES [NpmConnectors] ([NpmConnector_Id]),

	CONSTRAINT [FK__ScheduledTasks__MavenConnectors]
		FOREIGN KEY ([MavenConnector_Id])
		REFERENCES [MavenConnectors] ([MavenConnector_Id]),

	CONSTRAINT [CK__ScheduledTasks__Context]
		CHECK (([Feed_Id] IS NULL AND [MavenConnector_Id] IS NULL AND [NpmConnector_Id] IS NULL)
		    OR ([Feed_Id] IS NOT NULL AND [MavenConnector_Id] IS NULL AND [NpmConnector_Id] IS NULL)
			OR ([Feed_Id] IS NULL AND [MavenConnector_Id] IS NOT NULL AND [NpmConnector_Id] IS NULL)
			OR ([Feed_Id] IS NULL AND [MavenConnector_Id] IS NULL AND [NpmConnector_Id] IS NOT NULL)),

	CONSTRAINT [CK__ScheduledTasks__Frequency_Hours]
		CHECK ([Frequency_Hours] IS NULL OR [Frequency_Hours] > 0),

	CONSTRAINT [CK__ScheduledTasks__StartTimeOfDay_Minutes]
		CHECK ([StartTimeOfDay_Minutes] >= 0 AND [StartTimeOfDay_Minutes] < (24 * 60)),

	CONSTRAINT [CK__ScheduledTasks__EndTimeOfDay_Minutes]
		CHECK ([EndTimeOfDay_Minutes] >= 0 AND [EndTimeOfDay_Minutes] < (24 * 60))
)

CREATE TABLE [ScheduledTaskExecutions]
(
	[ScheduledTaskExecution_Id] INT IDENTITY(1, 1) NOT NULL,
	[ScheduledTask_Id] INT NOT NULL,
	[StartedOn_Date] DATETIME NOT NULL,
	[EndedOn_Date] DATETIME NULL,
	[HighestLogMessage_Level] INT NULL,
	[InitiatedBy_User] USERNAME NULL,

	CONSTRAINT [PK__ScheduledTaskExecutions]
		PRIMARY KEY ([ScheduledTaskExecution_Id]),

	CONSTRAINT [FK__ScheduledTaskExecutions__ScheduledTasks]
		FOREIGN KEY ([ScheduledTask_Id])
		REFERENCES [ScheduledTasks] ([ScheduledTask_Id])
)

CREATE TABLE [ScheduledTaskExecutionLogs]
(
	[ScheduledTaskExecution_Id] INT NOT NULL,
	[LogMessage_Sequence] INT NOT NULL,
	[LogMessage_Level] INT NOT NULL,
	[LogMessage_Text] VARBINARY(MAX) NOT NULL,

	CONSTRAINT [PK__ScheduledTaskExecutionLogs]
		PRIMARY KEY ([ScheduledTaskExecution_Id], [LogMessage_Sequence]),

	CONSTRAINT [FK__ScheduledTaskExecutionLogs__ScheduledTaskExecutions]
		FOREIGN KEY ([ScheduledTaskExecution_Id])
		REFERENCES [ScheduledTaskExecutions] ([ScheduledTaskExecution_Id])
)