EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Connectors_DeleteCachedResponse',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes the specified cached response. If Populated_Date and Request_Count are specified, the response is only deleted if they match.'
GO

IF OBJECT_ID('[Connectors_DeleteCachedResponse]') IS NOT NULL DROP PROCEDURE [Connectors_DeleteCachedResponse]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Connectors_DeleteCachedResponse]
(
	@ConnectorResponse_Id INT,
	@Populated_Date DATETIME = NULL,
	@Request_Count INT = NULL
)
AS BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DELETE
	  FROM [ConnectorResponses]
	 WHERE [ConnectorResponse_Id] = @ConnectorResponse_Id
	   AND [Populated_Date] = COALESCE(@Populated_Date, [Populated_Date])
	   AND [Request_Count] = COALESCE(@Request_Count, [Request_Count])

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Connectors_DeleteCachedResponse] TO [ProGetUser_Role]
GO
